Crate msrv_shims

Crate msrv_shims 

msrv-shims

This library re-exports various objects only defined in recent versions of Rust, enabling citing them via msrv-shims instead of std. This lets downstream consumers easily define their own custom MSRV policy by patching this dependency to have the necessary set of polyfills, without introducing those polyfills into the upstream trees.